@@ -1,4 +1,5 @@
-"""
+"""The CrowdStrike Falcon OAuth2 API SDK endpoints module
+
  @@@@@@@  @@@@@@@    @@@@@@   @@@  @@@  @@@  @@@@@@@    @@@@@@   @@@@@@@  @@@@@@@   @@@  @@@  @@@  @@@@@@@@
 @@@@@@@@  @@@@@@@@  @@@@@@@@  @@@  @@@  @@@  @@@@@@@@  @@@@@@@   @@@@@@@  @@@@@@@@  @@@  @@@  @@@  @@@@@@@@
 !@@       @@!  @@@  @@!  @@@  @@!  @@!  @@!  @@!  @@@  !@@         @@!    @@!  @@@  @@!  @@!  !@@  @@!
@@ -56,6 +57,7 @@ from ._mssp import _mssp_endpoints
 from ._oauth2 import _oauth2_endpoints
 from ._overwatch_dashboard import _overwatch_dashboard_endpoints
 from ._prevention_policies import _prevention_policies_endpoints
+from ._quarantine import _quarantine_endpoints
 from ._quick_scan import _quick_scan_endpoints
 from ._real_time_response import _real_time_response_endpoints
 from ._real_time_response_admin import _real_time_response_admin_endpoints
@@ -99,6 +101,7 @@ api_endpoints.extend(_mssp_endpoints)
 api_endpoints.extend(_oauth2_endpoints)
 api_endpoints.extend(_overwatch_dashboard_endpoints)
 api_endpoints.extend(_prevention_policies_endpoints)
+api_endpoints.extend(_quarantine_endpoints)
 api_endpoints.extend(_quick_scan_endpoints)
 api_endpoints.extend(_real_time_response_endpoints)
 api_endpoints.extend(_real_time_response_admin_endpoints)
